@@ -1,7 +1,7 @@
 import asyncio
 import json
 
-from ipaacar.components import IU, create_mqtt_pair, InputBuffer
+from ipaacar.components import IU, create_mqtt_pair
 
 from ipaacar.handler import IUCallbackHandlerInterface
 
